@@ -32,5 +32,5 @@ basedir = os.path.dirname(os.path.dirname(__file__))
 if basedir != '':
     sys.path.insert(0, basedir + '/share/hivemind')
 
-import hivemind.gui_main
-hivemind.gui_main.run()
+import hivemind.splash
+hivemind.splash.run()
