@@ -167,8 +167,8 @@ class DesktopMainWindow(AbstractMainWindow):
         toolbar.addAction(self._actionBag.undoAction)
         toolbar.addAction(self._actionBag.redoAction)
         toolbar = self._createToolBar(self.tr('View'), 'viewToolbar')
-        toolbar.addAction(self._actionBag.zoomOutAction)
         toolbar.addAction(self._actionBag.zoomInAction)
+        toolbar.addAction(self._actionBag.zoomOutAction)
         toolbar = self._createToolBar(self.tr('Connection status'),
                 'connectionStatusToolbar')
         toolbar.addAction(self._actionBag.connectionStatusAction)
@@ -183,7 +183,7 @@ class DesktopMainWindow(AbstractMainWindow):
     def showMenu(self, rightButton, item):
         '''Show the node menu on right button click'''
         if rightButton:
-            self.__contextMenu.exec_(QCursor.pos())
+            self.__contextMenu.popup(QCursor.pos())
 
     def closeEvent(self, event):
         '''
