@@ -27,8 +27,7 @@ Main window classes
 
 '''Install and start QtReactor'''
 import sys
-from PyQt4.QtGui import QApplication
-app = QApplication(sys.argv)
+
 from qt4reactor import qt4reactor
 qt4reactor.install()
 from hivemind.network import network_core
@@ -39,7 +38,8 @@ import os
 import re
 from twisted.python import log
 from PyQt4.QtGui import QActionGroup, QGraphicsBlurEffect, QMessageBox, QUndoStack, \
-QFileDialog, QPixmap, QPainter, QAction, QDesktopServices, QPrintDialog, QPrinter, QUndoCommand
+QFileDialog, QPixmap, QPainter, QAction, QDesktopServices, QPrintDialog, QPrinter, \
+QUndoCommand
 from PyQt4.QtCore import QObject, SIGNAL, QTimer, QLocale, QTranslator, QLibraryInfo, \
 Qt, QRectF, QUrl
 import hivemind.gui_factory as gui_factory
@@ -71,8 +71,13 @@ class MainWindowController(QObject):
     MODE_TRANSFER = 'transfer'
     '''Map is in transfer mode'''
 
-    def __init__(self):
+    def __init__(self, splashScreen):
+        '''
+        @param splashScreen: splash screen widget
+        @type splashScreen: QSplashScreen
+        '''
         QObject.__init__(self)
+
         '''Init widgets and configure application'''
         self.__findWidget = None
         self.__movingNode = None
@@ -89,7 +94,7 @@ class MainWindowController(QObject):
         self.__networkController = network_core.NetworkController(
                 self.__mindMapController, self.__actionBag)
         self.__smartConferenceRobot = SmartConferenceRobot(self.__mindMapScene,
-                self.__networkController)
+                self.__networkController, self.__actionBag)
         self.__actionBag.startSmartConferenceRobot.triggered.connect(
                 self.__smartConferenceRobot.start)
         self.__actionBag.stopSmartConferenceRobot.triggered.connect(
@@ -97,8 +102,9 @@ class MainWindowController(QObject):
         QObject.connect(self.__mainWindow.mindMapView, SIGNAL('itemClicked'),
                 adaptCallable(self.onItemClicked))
         self.__mainWindow.closeEvnt.connect(self._closeEvent)
-        _configureApplication(self.__mindMapController)
+        splashScreen.finish(self.__mainWindow)
         self.__mainWindow.showMaximized()
+        _configureApplication(self.__mindMapController)
 
     def _setActionsState(self, currentNode):
         '''
@@ -486,14 +492,14 @@ class MainWindowController(QObject):
         parentNode = self.__mindMapScene.currentNode
         def _accept():
             '''Process accept action'''
-            if self.__mindMapScene.currentNode.parent is None:
+            if parentNode.parent is None:
                 dialog = gui_factory.createSideSelectionDialog()
                 dialog.exec_()
                 if dialog.leftSide is None:
                     # User doesn't accept dialog
                     return
                 childNode.setAttributes(left = dialog.leftSide)
-            if self.__mindMapScene.currentNode.folded:
+            if parentNode.folded:
                 self.foldNode()
             childNode.setAttributes(**editor.attributes())
             self._recordCommand(AddNodeCommand(parentNode, childNode))
@@ -764,7 +770,6 @@ class MindMapController(QObject):
         '''
         command = parser.deserializeCommand(command, self.__mindMapScene.mindMap)
         self.executeCommand(command)
-        self.storeCommand(command)
 
     def storeCommand(self, command):
         '''
@@ -780,7 +785,7 @@ class MindMapController(QObject):
         @param command: command to execute
         '''
         if isinstance(command, QUndoCommand):
-            command.redo()
+            self.storeCommand(command)
         elif isinstance(command, ActionCommand):
             {'undo': self.__undoStack.undo, 'redo': self.__undoStack.redo}[command.action]()
         elif isinstance(command, CurrentNodeCommand):
@@ -970,8 +975,12 @@ def _getLocale():
         settings.set(locale = locale)
     return locale
 
-def run():
-    '''Run HiveMind application'''
+def run(app, splashScreen):
+    '''
+    Run HiveMind application
+    @type app: QApplication
+    @type splashScreen: QSplashScreen
+    '''
     # translator installation
     locale = _getLocale()[0:2]
     translatorStd = QTranslator()
@@ -981,5 +990,5 @@ def run():
     translator = QTranslator()
     if translator.load(sysconfig.TRANSLATION_PATH_TEMPLATE % locale):
         app.installTranslator(translator)
-    MainWindowController()
+    MainWindowController(splashScreen)
     sys.exit(app.exec_())
