@@ -33,11 +33,11 @@ QAction, QUndoCommand, QLineEdit, QSpinBox, QCheckBox, QComboBox, QLabel, \
 QToolButton, QIcon, QApplication, QFormLayout, QFontComboBox, QFontDatabase, \
 QHBoxLayout, QGraphicsBlurEffect, QFrame, QPalette, QPushButton, \
 QColorDialog, QPainter, QKeyEvent, QPixmap, QListView, QKeySequence, QToolBar, \
-QFont, QImage
+QFont
 from hivemind.attribute import readable
 from PyQt4.QtCore import QAbstractAnimation, QObject, SIGNAL, QLocale, Qt, \
 QRect, QEvent, QRectF, QSize, QParallelAnimationGroup, QPropertyAnimation, \
-QPointF, QRegExp, SLOT, QSequentialAnimationGroup, QEasingCurve, QTimer
+QPointF, QRegExp, QSequentialAnimationGroup, QEasingCurve, QTimer, pyqtSignal
 from hivemind.gui_delegates import NodeFinder
 
 
@@ -104,6 +104,8 @@ class SpecialTextEdit(QTextEdit):
     @author: Alexander Kulikov
     '''
 
+    accept = pyqtSignal()
+
     def __init__(self, parent = None):
         '''
         Initialize widget
@@ -119,7 +121,7 @@ class SpecialTextEdit(QTextEdit):
         if event.key() == Qt.Key_Return or event.key() == Qt.Key_Enter:
             modifier = event.modifiers() & ~Qt.KeypadModifier
             if modifier == Qt.NoModifier:
-                self.emit(SIGNAL('accept'))
+                self.accept.emit()
                 return
             if modifier == Qt.ControlModifier:
                 event = QKeyEvent(QEvent.KeyPress, event.key(), Qt.NoModifier)
@@ -180,7 +182,9 @@ class ListWidgetItem(QListWidgetItem):
     List widget item for drawing icons in icon table
     @author: Alexander Kulikov
     '''
+
     readable('icon')
+
     def __init__(self, icon, parent = None):
         QListWidgetItem.__init__(self, parent)
         self.__icon = icon
@@ -213,7 +217,7 @@ class IconTable(QListWidget):
         for icon in settings.get("listIcons"):
             item = ListWidgetItem(icon)
             self.addItem(item)
-        QObject.connect(self, SIGNAL('itemClicked(QListWidgetItem*)'), self._onClick)
+        self.itemClicked[QListWidgetItem].connect(self._onClick)
 
     def _onClick(self, item):
         '''Emit iconClicked signal on item click'''
@@ -449,9 +453,9 @@ class ActionImageButton(QAbstractButton):
     def _connectToAction(self):
         '''Create connections to the action state and property changes and enable acction
         trigger on button click'''
-        QObject.connect(self.__action, SIGNAL('changed()'), self._syncProperties)
-        QObject.connect(self.__action, SIGNAL('toggled(bool)'), self.setChecked)
-        QObject.connect(self, SIGNAL('clicked()'), self.__action.trigger)
+        self.__action.changed.connect(self._syncProperties)
+        self.__action.toggled.connect(self.setChecked)
+        self.clicked.connect(self.__action.trigger)
 
     def _setupSizeHint(self, sizeHint):
         '''
@@ -564,6 +568,7 @@ class WidgetVisibilityAnimation(QAbstractAnimation):
 
     def duration(self):
         '''Animation is instant'''
+        #pylint: disable = R0201
         return 0
 
 
@@ -742,7 +747,7 @@ class SettingsCreator(QObject):
         layout.addWidget(binder, Qt.AlignLeft)
         layout.addWidget(binderButton, Qt.AlignLeft)
         self.__mainLayout.addRow(self.tr('Text color'), layout)
-        QObject.connect(binderButton, SIGNAL('clicked()'), binder.open)
+        binderButton.clicked.connect(binder.open)
         self.__component['defaultNodeTextColor'] = binder
 
     def _createDefaultNodeBackgroundColor(self):
@@ -756,7 +761,7 @@ class SettingsCreator(QObject):
         layout.addWidget(binder, Qt.AlignLeft)
         layout.addWidget(binderButton, Qt.AlignLeft)
         self.__mainLayout.addRow(self.tr('Background color'), layout)
-        QObject.connect(binderButton, SIGNAL('clicked()'), binder.open)
+        binderButton.clicked.connect(binder.open)
         self.__component['defaultNodeBackgroundColor'] = binder
 
     def _createDefaultEdgeColor(self):
@@ -770,7 +775,7 @@ class SettingsCreator(QObject):
         layout.addWidget(binder, Qt.AlignLeft)
         layout.addWidget(binderButton, Qt.AlignLeft)
         self.__mainLayout.addRow(self.tr('Edge color'), layout)
-        QObject.connect(binderButton, SIGNAL('clicked()'), binder.open)
+        binderButton.clicked.connect(binder.open)
         self.__component['defaultEdgeColor'] = binder
 
     def _createDefaultLabelColor(self):
@@ -784,7 +789,7 @@ class SettingsCreator(QObject):
         layout.addWidget(binder, Qt.AlignLeft)
         layout.addWidget(binderButton, Qt.AlignLeft)
         self.__mainLayout.addRow(self.tr('Label color'), layout)
-        QObject.connect(binderButton, SIGNAL('clicked()'), binder.open)
+        binderButton.clicked.connect(binder.open)
         self.__component['defaultLabelColor'] = binder
 
     def _createDefaultEdgeWidth(self):
@@ -808,7 +813,7 @@ class SettingsCreator(QObject):
         layout.addWidget(binder, Qt.AlignLeft)
         layout.addWidget(binderButton, Qt.AlignLeft)
         self.__mainLayout.addRow(self.tr('Selected node background'), layout)
-        QObject.connect(binderButton, SIGNAL('clicked()'), binder.open)
+        binderButton.clicked.connect(binder.open)
         self.__component['defaultSelectedNodeBackgroundColor'] = binder
 
     def _createAutosaveEnabled(self):
@@ -889,27 +894,27 @@ class SettingsCreator(QObject):
         '''
         Create shortcuts table component
         '''
-        shortcuts = [('addNodeShortcut', self.tr('Add Node')),
-                ('addSiblingNodeBelowShortcut', self.tr('Add Sibling Node Below')),
-                ('addSiblingNodeAboveShortcut', self.tr('Add Sibling Node Above')),
-                ('editNodeShortcut', self.tr('Edit Node')),
-                ('removeNodeShortcut', self.tr('Remove Node')),
-                ('editEdgeShortcut', self.tr('Edit Edge')),
-                ('editLabelShortcut', self.tr('Edit Label')),
-                ('editNodeIconsShortcut', self.tr('Edit Node Icons')),
-                ('foldNodeShortcut', self.tr('Fold Node')),
-                ('editHyperlinkShortcut', self.tr('Edit Hyperlink')),
-                ('openHyperlinkShortcut', self.tr('Open Hyperlink')),
-                ('selectLeftNodeShortcut', self.tr('Select Left Node')),
-                ('selectRightNodeShortcut', self.tr('Select Right Node')),
-                ('selectUpNodeShortcut', self.tr('Select Up Node')),
-                ('selectDownNodeShortcut', self.tr('Select Down Node')),
-                ('selectRootNodeShortcut', self.tr('Select Root Node')),
-                ('enterTransferModeShortcut', self.tr('Enter Transfer Mode')),
-                ('cancelTransferModeShortcut', self.tr('Cancel Transfer Mode')),
-                ('putNodeShortcut', self.tr('Put Node')),
-                ('putNodeBelowShortcut', self.tr('Put Node Below')),
-                ('putNodeAboveShortcut', self.tr('Put Node Above'))]
+        shortcuts = [('addNodeShortcut', self.tr('Add child node')),
+                ('addSiblingNodeBelowShortcut', self.tr('Add sibling node below')),
+                ('addSiblingNodeAboveShortcut', self.tr('Add sibling node above')),
+                ('editNodeShortcut', self.tr('Edit node')),
+                ('removeNodeShortcut', self.tr('Remove node')),
+                ('editEdgeShortcut', self.tr('Edit edge')),
+                ('editLabelShortcut', self.tr('Edit label')),
+                ('editNodeIconsShortcut', self.tr('Edit node icons')),
+                ('foldNodeShortcut', self.tr('Fold node')),
+                ('editHyperlinkShortcut', self.tr('Edit nyperlink')),
+                ('openHyperlinkShortcut', self.tr('Open nyperlink')),
+                ('selectLeftNodeShortcut', self.tr('Select left node')),
+                ('selectRightNodeShortcut', self.tr('Select right node')),
+                ('selectUpNodeShortcut', self.tr('Select up node')),
+                ('selectDownNodeShortcut', self.tr('Select down node')),
+                ('selectRootNodeShortcut', self.tr('Select root node')),
+                ('enterTransferModeShortcut', self.tr('Enter transfer mode')),
+                ('cancelTransferModeShortcut', self.tr('Cancel transfer mode')),
+                ('putNodeShortcut', self.tr('Put node')),
+                ('putNodeBelowShortcut', self.tr('Put node below')),
+                ('putNodeAboveShortcut', self.tr('Put node above'))]
         binder = ComponentBinderGroup()
         for shortcut in shortcuts:
             editor = ShortcutEditBinder(shortcut[0], settings.get(shortcut[0]))
@@ -1075,7 +1080,7 @@ class ShortcutEditBinder(QLineEdit, ComponentBinder):
         self.setReadOnly(True)
         self.__state = self.__NORMAL_STATE
         self.__oldShortcut = ''
-        QObject.connect(self, SIGNAL('textChanged()'), self._setValue)
+        self.textChanged.connect(self._setValue)
 
     def mousePressEvent(self, event):
         '''
@@ -1171,7 +1176,7 @@ class SpinBoxBinder(QSpinBox, ComponentBinder):
         self.setMaximum(maxValue)
         self.setValue(value)
         self._value = value
-        QObject.connect(self, SIGNAL('valueChanged(int)'), self._setValue)
+        self.valueChanged.connect(self._setValue)
 
 
 class CheckBoxBinder(QCheckBox, ComponentBinder):
@@ -1218,7 +1223,7 @@ class ComboBoxBinder(QComboBox, ComponentBinder):
         for values in data:
             self.addItem(values.keys().pop(), values.values().pop())
         self.setCurrentIndex(self.findData(value))
-        QObject.connect(self, SIGNAL('activated(int)'), self._setValue)
+        self.activated.connect(self._setValue)
 
     def _setValue(self, index):
         '''
@@ -1299,8 +1304,8 @@ class FontBinder(QWidget, ComponentBinder):
         self.__fontCombo = QFontComboBox()
         self.__fontCombo.setCurrentFont(font)
         self._setFont(font)
-        QObject.connect(self.__fontCombo, SIGNAL('currentFontChanged(QFont)'), self._setFont)
-        QObject.connect(self.__sizeCombo, SIGNAL('currentIndexChanged(int)'), self._setSize)
+        self.__fontCombo.currentFontChanged.connect(self._setFont)
+        self.__sizeCombo.currentIndexChanged.connect(self._setSize)
 
     def _setFont(self, font):
         '''
@@ -1368,7 +1373,7 @@ class FullScreenExitButton(QToolButton):
         self.setPalette(pal)
         self.setAutoFillBackground(True)
         self.setVisible(False)
-        QObject.connect(self, SIGNAL('clicked()'), parent, SLOT('showNormal()'))
+        self.clicked.connect(parent.showNormal)
         parent.installEventFilter(self)
 
     def eventFilter(self, obj, event):
@@ -1399,6 +1404,9 @@ class MaemoNodeMenu(QObject):
     @author: Andrew Vasilev, Alexander Kulikov
     '''
     readable('item')
+
+    isShowed = pyqtSignal()
+
     def __init__(self, parent):
         '''
         @param parent: the main scene view to place menu on top of
@@ -1413,11 +1421,11 @@ class MaemoNodeMenu(QObject):
         self.__hideAnimationTransformation = None
         self.__radiusOne = self.__radiusTwo = None
         self.__item = None
-        QObject.connect(parent, SIGNAL('mapClicked'), self.hideMenu)
+        parent.mapClicked.connect(self.hideMenu)
         self.__hideMenuTimer = QTimer(self)
         self.__hideMenuTimer.setInterval(settings.get('autoHideNodeMenuTimeout'))
         self.__hideMenuTimer.setSingleShot(True)
-        QObject.connect(self.__hideMenuTimer, SIGNAL('timeout()'), self.hideMenu)
+        self.__hideMenuTimer.timeout.connect(self.hideMenu)
 
     __INITIAL_ANGLE = math.pi * 1.2
     '''Start angle for button positioning'''
@@ -1440,7 +1448,7 @@ class MaemoNodeMenu(QObject):
         '''
         self._menuButtons[action] = button
         button.hide()
-        QObject.connect(button, SIGNAL('clicked()'), self.hideMenu)
+        button.clicked.connect(self.hideMenu)
 
     def _restartHideMenuTimer(self):
         '''Restart hide menu timer'''
@@ -1652,7 +1660,7 @@ class MaemoNodeMenu(QObject):
         @type item: NodeDelegate
         '''
         self.__item = item
-        self.emit(SIGNAL('show'))
+        self.isShowed.emit()
         self._evaluateMenuBoundaries(item)
         self._positionMenu()
         self._restartHideMenuTimer()
@@ -1707,7 +1715,7 @@ class MaemoSidePanel(QObject):
         self.__hideAnimation = QParallelAnimationGroup()
         self.__sidebarButton = ActionImageButton(sidebarAction, self.__mapView)
         self.__sidebarButton.move(0, self.__SIDEBAR_BUTTON_POSITION)
-        QObject.connect(sidebarAction, SIGNAL('triggered()'), self._startAnimation)
+        sidebarAction.triggered.connect(self._startAnimation)
 
     def _startAnimation(self):
         '''Start various animations according to sidebar status'''
@@ -1759,7 +1767,7 @@ class MaemoSidePanel(QObject):
         showMovementAnimation.setEndValue(QRect(self.__SIZE + self.__DISTANCE, 360,
                 self.__SIZE, self.__SIZE))
         self.__showAnimation.addAnimation(showMovementAnimation)
-        QObject.connect(self.__showAnimation, SIGNAL('finished()'), self._toggleSidebarStatus)
+        self.__showAnimation.finished.connect(self._toggleSidebarStatus)
 
     def _generateHideAnimation(self):
         '''Generate hide animation'''
@@ -1781,7 +1789,7 @@ class MaemoSidePanel(QObject):
                 self.__SIDEBAR_BUTTON_POSITION, self.__SIZE, self.__SIZE))
         hideMovementAnimation.setEndValue(QRect(0, 360, self.__SIZE, self.__SIZE))
         self.__hideAnimation.addAnimation(hideMovementAnimation)
-        QObject.connect(self.__hideAnimation, SIGNAL('finished()'), self._toggleSidebarStatus)
+        self.__hideAnimation.finished.connect(self._toggleSidebarStatus)
 
 
 class FindToolBar(SearchingTrMixin, QToolBar):
@@ -1798,6 +1806,12 @@ class FindToolBar(SearchingTrMixin, QToolBar):
         self.setWindowTitle(self.tr('Find'))
         self._finder = NodeFinder(controller)
 
+    def setDefaultFocus(self):
+        '''
+        Set focus on default item
+        '''
+        self._findLineEdit.setFocus()
+
     def _createComponents(self):
         '''
         Create components
@@ -1809,18 +1823,19 @@ class FindToolBar(SearchingTrMixin, QToolBar):
         self._highlightCheckBox = QCheckBox(self.tr("&Highlight all"))
         self._caseSensitiveCheckBox = QCheckBox(self.tr("Case &sensitive"))
         self._statusLabel = QLabel()
-        QObject.connect(self._highlightCheckBox, SIGNAL('clicked(bool)'), self._finder.highlightNodes)
-        QObject.connect(self._caseSensitiveCheckBox, SIGNAL('clicked()'), self._updateFinder)
-        QObject.connect(self._findLineEdit, SIGNAL('textEdited(QString)'), self._updateFinder)
+        self._highlightCheckBox.clicked.connect(self._finder.highlightNodes)
+        self._caseSensitiveCheckBox.clicked.connect(self._updateFinder)
+        self._findLineEdit.textEdited.connect(self._updateFinder)
         QObject.connect(self, SIGNAL('visibilityChanged(bool)'), self._updateFinder)
-        QObject.connect(self._finder, SIGNAL('statusChanged'), self._updateStatusLabel)
+        self._finder.statusChanged.connect(self._updateStatusLabel)
 
     def _updateFinder(self):
         '''
         Update finder
         '''
         if self.isVisible():
-            self._finder.findNodes(self._findLineEdit.text(), self._caseSensitiveCheckBox.isChecked(),
+            self._finder.findNodes(self._findLineEdit.text(),
+                    self._caseSensitiveCheckBox.isChecked(),
                     self._highlightCheckBox.isChecked())
         else:
             self._finder.findNodes('')
