@@ -31,11 +31,11 @@ Provides functions for creating a mind map object from XML file and vice versa
 import parser #pylint: disable=W0406
 
 from lxml import etree as xml
-from PySide.QtCore import QFile, QIODevice, QTextStream
-from PySide.QtGui import QTextDocument, QColor, QFont, QUndoStack
+from PyQt4.QtCore import QFile, QIODevice, QTextStream
+from PyQt4.QtGui import QTextDocument, QColor, QFont, QUndoStack
 from hivemind.core import Node, MindMap, Cloud, Attribute, AttributeRegistry
 from hivemind.commands import AddNodeCommand, MoveNodeCommand, RemoveNodeCommand, \
-StateModificationCommand
+StateModificationCommand, ActionCommand, CurrentNodeCommand
 
 
 def _parseNode(root, parent = None):
@@ -58,8 +58,8 @@ def _parseNode(root, parent = None):
     if nodeText is not None: storeAttrs['text'] = nodeText
     nodeStyle = attributes.pop('style', None)
     if nodeStyle is not None: storeAttrs['style'] = nodeStyle
-    nodePosition = attributes.pop('position', None)
-    if nodePosition is not None: storeAttrs['left'] = nodePosition == 'left'
+    nodePosition = attributes.pop('left', None)
+    if nodePosition is not None: storeAttrs['left'] = nodePosition
     nodeColor = attributes.pop('color', None)
     if nodeColor is not None: storeAttrs['color'] = nodeColor
     backgroundColor = attributes.pop('background_color', None)
@@ -132,7 +132,7 @@ __INTEGERS = set(('created', 'modified', 'hgap', 'vgap', 'vshift',
 __WIDTHS = set(('width', 'edgeWidth'))
 '''Width holding attributes'''
 
-__COLORS = set(('color', 'background_color', 'edgeColor', 'labelColor'))
+__COLORS = set(('color', 'background_color', 'edgeColor', 'labelColor', 'backgroundColor'))
 '''QColor attributes'''
 
 __FONTS = set(('font', 'labelFont'))
@@ -142,19 +142,24 @@ __BOOLEANS = set(('folded', 'propagate_formatting', 'propagateNodeFormatting',
         'propagateLabelFormatting'))
 '''Attribute that store boolean values'''
 
-def _castAttributes(attributes, toLowerCase = True):
+__NEW_LINE = '?_newline_?'
+'''Special value to replace \n in network mode in node text attribute'''
+
+def _castAttributes(attributes, fileMode = True):
     '''
     Cast attribute values from string to more convenient type
 
     @param attributes: dict of objects to casting
     @type attributes: dict
 
-    @param toLowerCase: if True, attribute names will be converted to lover case
-    @type toLowerCase: bool
+    @param fileMode: if True, attribute names will be converted to lover case and
+    \n won't be replaced in node text attribute
+    @type fileMode: bool
     '''
     casted = {}
     for attrName, attrValue in attributes.items():
-        if toLowerCase: attrName = attrName.lower()
+        if fileMode: attrName = attrName.lower()
+        if attrName == 'position': attrName = 'left'
         if attrValue == "":
             casted[attrName] = None
         elif attrName in __INTEGERS:
@@ -166,7 +171,10 @@ def _castAttributes(attributes, toLowerCase = True):
             # in paint context. For compatibility used mod10(width) value
             casted[attrName] = 11 if attrValue == 'thin' else int(attrValue)
         elif attrName in __BOOLEANS:
-            casted[attrName] = True
+            if attrValue.lower() == 'true':
+                casted[attrName] = True
+            else:
+                casted[attrName] = False
         elif attrName in __FONTS:
 #           Font attribute is a comma-separated list of the attributes of QFont object.
 #           To get this attribute use QFont::toString() method
@@ -180,26 +188,33 @@ def _castAttributes(attributes, toLowerCase = True):
             casted[attrName] = font
         elif attrName == 'icons':
             casted[attrName] = eval(attrValue, None, None)
+        elif attrName == 'text' and not fileMode:
+            casted[attrName] = attrValue.replace(__NEW_LINE, '\n')
+        elif attrName == 'left':
+            casted[attrName] = True if attrValue == 'left' else False
         else:
             casted[attrName] = attrValue
     return casted
 
-def _toString(attributes, toUpperCase = True):
+def _toString(attributes, fileMode = True):
     '''
     Cast various type objects to string
 
     @param attributes: dict of objects to casting
     @type attributes: dict
 
-    @param toUpperCase: if True, attribute names will be converted to upper case
-    @type toUpperCase: bool
+    @param fileMode: if True, attribute names will be converted to upper case and boolean
+    attributes won't be saved
+    @type fileMode: bool
 
     @return: modified attributes
     @rtype: dict
     '''
     stringAttributes = {}
     for attrName, attrValue in attributes.items():
-        strAttrKey = attrName.upper() if toUpperCase else attrName
+        if attrName == 'left':
+            attrName = 'position'
+        strAttrKey = attrName.upper() if fileMode else attrName
         if attrValue is None:
             stringAttributes[strAttrKey] = ""
         elif attrName in __COLORS:
@@ -207,13 +222,17 @@ def _toString(attributes, toUpperCase = True):
         # replace 'True' with FreeMind format specified value 'true'
         elif attrName in __BOOLEANS:
             if attrValue is True:
-                stringAttributes[strAttrKey] = 'true' # value 'false' not stored in file
+                stringAttributes[strAttrKey] = 'true'
+            elif not fileMode: # send 'false' value over the network
+                stringAttributes[strAttrKey] = 'false'
         elif attrName == 'width':
             stringAttributes[strAttrKey] = str(attrValue) if attrValue != 11 else 'thin'
         elif attrName == 'font':
             stringAttributes[strAttrKey] = unicode(attrValue.toString())
-        elif attrName == 'left':
-            stringAttributes['POSITION'] = 'left' if attrValue else 'right'
+        elif attrName == 'position':
+            stringAttributes[strAttrKey] = 'left' if attrValue else 'right'
+        elif attrName == 'text' and not fileMode:
+            stringAttributes[strAttrKey] = attrValue.replace('\n', __NEW_LINE)
         else:
             stringAttributes[strAttrKey] = unicode(attrValue)
     return stringAttributes
@@ -478,7 +497,10 @@ def _fillAddNodeCommandElement(command, commandElement):
     if command.childIndex is not None:
         parentElement.set('childIndex', str(command.childIndex))
     commandElement.append(parentElement)
-    commandElement.append(_nodeToXml(command.childNode))
+    node = xml.Element('node')
+    node.attrib.update(_toString(command.childNode.getAttributes(getAll = True),
+            fileMode = False))
+    commandElement.append(node)
 
 
 def _fillMoveNodeCommandElement(command, commandElement):
@@ -522,20 +544,32 @@ def _fillStateModificationCommandElement(command, commandElement):
     '''
     commandElement.append(xml.Element('node', id = command.node.id))
     stateAfter = xml.Element('state_after')
-    stateAfter.attrib.update(_toString(command.stateAfter, toUpperCase = False))
+    stateAfter.attrib.update(_toString(command.stateAfter, fileMode = False))
     commandElement.append(stateAfter)
 
-def _fillstrElement(command, commandElement):
+def _fillActionCommandElement(command, commandElement):
     '''
     Add required content to string XML element
 
     @param command: command object
-    @type command: str
+    @type command: ActionCommand
 
     @param commandElement: XML element for processing
     @type commandElement: lxml Element
     '''
-    commandElement.append(xml.Element('action', type = command))
+    commandElement.append(xml.Element('action', type = command.action))
+
+def _fillCurrentNodeCommandElement(command, commandElement):
+    '''
+    Add required content to string XML element
+
+    @param command: command object
+    @type command: CurrentNodeCommand
+
+    @param commandElement: XML element for processing
+    @type commandElement: lxml Element
+    '''
+    commandElement.append(xml.Element('node', id = command.node.id))
 
 def _commandToXml(command):
     '''
@@ -599,7 +633,9 @@ def _deserializeAddNodeCommand(commandElement, mindMap):
     parentElement = commandElement[0]
     parent = mindMap.getNodeById(parentElement.get('id'))
     nodeElement = commandElement[1]
-    child = _parseNode(nodeElement, parent)
+    nodeAttributes = _castAttributes(nodeElement.attrib, fileMode = False)
+    child = parent.createChildPrototype()
+    child.setAttributes(**nodeAttributes)
     if child.left is None: child.setAttributes(left = parent.left)
     index = parentElement.get('childIndex')
     if index is not None:
@@ -638,18 +674,28 @@ def _deserializeStateModificationCommand(commandElement, mindMap):
     nodeElement = commandElement[0]
     node = mindMap.getNodeById(nodeElement.get('id'))
     afterElement = commandElement[1]
-    stateAfter = _castAttributes(afterElement.attrib, toLowerCase = False)
+    stateAfter = _castAttributes(afterElement.attrib, fileMode = False)
     stateBefore = node.getAttributes(*stateAfter.keys())
     return StateModificationCommand(node, stateBefore, stateAfter)
 
-def _deserializestr(commandElement, mindMap):
+def _deserializeActionCommand(commandElement, mindMap):
     '''
-    Deserialize string command from XML string
+    Deserialize action command from XML string
 
-    @rtype: str
+    @rtype: ActionCommand
     '''
     nodeElement = commandElement[0]
-    return nodeElement.get('type')
+    return ActionCommand(nodeElement.get('type'))
+
+def _deserializeCurrentNodeCommand(commandElement, mindMap):
+    '''
+    Deserialize current node command from XML string
+
+    @rtype: CurrentNodeCommand
+    '''
+    nodeElement = commandElement[0]
+    node = mindMap.getNodeById(nodeElement.get('id'))
+    return CurrentNodeCommand(node)
 
 def _xmlToCommand(commandElement, mindMap):
     '''
